package org.apache.commons.lang3.function;

import java.lang.Throwable;
import java.util.Objects;

/* loaded from: org_apache_commons_lang3_function.jar:org/apache/commons/lang3/function/FailableIntUnaryOperator.class */
public interface FailableIntUnaryOperator<E extends Throwable> {
    public static final FailableIntUnaryOperator NOP = t -> {
        return 0;
    };

    int applyAsInt(int i) throws Throwable;

    static <E extends Throwable> FailableIntUnaryOperator<E> identity() {
        return t -> {
            return t;
        };
    }

    static <E extends Throwable> FailableIntUnaryOperator<E> nop() {
        return NOP;
    }

    default FailableIntUnaryOperator<E> andThen(FailableIntUnaryOperator<E> after) {
        Objects.requireNonNull(after);
        return t -> {
            return after.applyAsInt(applyAsInt(t));
        };
    }

    default FailableIntUnaryOperator<E> compose(FailableIntUnaryOperator<E> before) {
        Objects.requireNonNull(before);
        return v -> {
            return applyAsInt(before.applyAsInt(v));
        };
    }
}
